@@ -215,7 +215,7 @@ def MotionMetrics (data,bodyPart,filter=0,fps=30,max_real=60,min_real=0):
         The input tracking data.
     bodyPart : str
         Body part you want use as reference.
-    filter : int
+    filter : float
         Threshold to remove motion artifacts. Adjust according to the tracking 
         quality and speed of what is moving.   
     fps : int
@@ -345,6 +345,7 @@ def Interaction(data,bodyPart,fields):
     -----
     This function was developed based on DLC outputs and is able to support 
     matplotlib configurations.""" 
+
     import numpy as np
     import pandas as pd
 
@@ -386,4 +387,70 @@ def Interaction(data,bodyPart,fields):
     df = pd.DataFrame([[start,end,obj]],columns=['start','end','obj'])
     interactsDf = interactsDf.append(df, ignore_index=True)
 
-    return interactsDf
\ No newline at end of file
+    return interactsDf
+
+def Reports(paths,bodypart,fields=None,filter=0.3,fps = 30):
+    """
+    Produces a report of all data passed along the way with movement and interaction metrics in a 
+    given box space.
+
+    Parameters
+    ----------
+    path : dict
+        Dictionary with all data paths.
+    bodypart : str
+        Body part you want use as reference.
+    fields : pandas DataFrame
+        The DataFrame with the coordinates of the created fields (output of FieldDetermination()).   
+    filter : float
+        Threshold to remove motion artifacts. Adjust according to the tracking 
+        quality and speed of what is moving.
+    fps : int
+        The recording frames per second.
+
+    Returns
+    -------
+    out : pandas DataFrame
+        DataFrame with report of each data in one line.
+
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+
+    Notes
+    -----
+    This function was developed based on DLC outputs and is able to support 
+    matplotlib configurations.""" 
+
+    import numpy as np
+    import pandas as pd
+    import pyrat as rat
+
+    relatorio = pd.DataFrame(columns=['file','time','dist', 'speed'])
+  
+    if type(fields) != type(None):  
+        for i in range(len(fields)):
+            relatorio["obj{0}".format(i+1)] = []
+            relatorio["time_obj{0}".format(i+1)] = []
+    for item in paths:
+        lista = [item]
+        data = pd.read_csv(paths[item])
+
+    DF = rat.MotionMetrics(data, bodypart, filter=filter, fps=fps)
+
+    time = DF.Time.iloc[-1]
+    dist = DF.Distance.sum()
+    vMedia = DF.Speed.mean()
+    
+    lista.append(time)
+    lista.append(dist)
+    lista.append(vMedia)
+    if type(fields) != type(None): 
+        interacts = rat.Interaction(data, bodypart, fields)
+        for i in range(len(fields)):
+            lista.append(interacts["obj"][interacts["obj"] == i+1].count())
+            lista.append((interacts["end"][interacts["obj"] == i+1]-interacts["start"][interacts["obj"] == i+1]).sum())
+    relatorio_temp = pd.DataFrame([lista], columns=relatorio.columns)
+    relatorio = relatorio.append(relatorio_temp, ignore_index=True)
+
+    return relatorio
\ No newline at end of file
